pub enum ExtremumKind {
NodeCandidate,
AntinodeCandidate,
}Expand description
Physical interpretation of a strict local scalar extremum.
Variants
NodeCandidate
Strict local minimum and therefore a possible destructive node.
AntinodeCandidate
Strict local maximum and therefore a possible constructive antinode.