HostPhasorFieldError

Enum HostPhasorFieldError 

pub enum HostPhasorFieldError {
    ZeroDimension {
        axis: &'static str,
    },
    ShapeMismatch {
        rows: usize,
        columns: usize,
        real_len: usize,
        imaginary_len: usize,
    },
    NonFinite {
        component: &'static str,
        index: usize,
        value: f64,
    },
}
A host phasor component buffer was not a valid finite two-dimensional field.

Variants



ZeroDimension

A component plane dimension was zero.

Fields

axis: &'static str

Rejected dimension.



ShapeMismatch

The row/column product overflowed or did not match both component lengths.

Fields

rows: usize

Declared row count.

columns: usize

Declared column count.

real_len: usize

Real component length.

imaginary_len: usize

Imaginary component length.



NonFinite

One component contained a NaN or infinity.

Fields

component: &'static str

Component plane.

index: usize

Row-major cell index.

value: f64

Rejected value.