pub enum ScalarSample {
Value(f64),
Masked,
}Expand description
One projected cell, with undefined values represented outside the numbers.
Variants
Value(f64)
A finite scalar value.
Masked
Phase is undefined because amplitude is at or below the declared floor.