pub enum ScenarioKind {
TwoPoint,
CounterPropagatingPlanes,
PhasedArray,
DiscreteAperture,
}Expand description
Named approximation created by a scenario builder.
Variants
TwoPoint
Two ideal isotropic point sources.
CounterPropagatingPlanes
Two ideal plane waves directed into their shared slab.
PhasedArray
A centred line of ideal isotropic point elements with progressive phase.
DiscreteAperture
A centred rectangular grid of ideal isotropic point elements.