pub struct DetectorFootprint { /* private fields */ }Expand description
Inclusive bounds on the source-cell rectangle represented by one target cell.
Implementations
Sourceimpl DetectorFootprint
impl DetectorFootprint
Sourcepub fn min_columns(self) -> usize
pub fn min_columns(self) -> usize
Returns the smallest number of source columns in a target cell.
Sourcepub fn max_columns(self) -> usize
pub fn max_columns(self) -> usize
Returns the largest number of source columns in a target cell.