pub struct MultiToneProjection { /* private fields */ }Expand description
A complete scalar observation of one certified multi-tone study.
Implementations
Sourceimpl MultiToneProjection
impl MultiToneProjection
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether the result contains no cells.
A valid multi-tone projection is never empty because its checked sampling plane has non-zero dimensions.
Sourcepub fn combination(&self) -> ToneCombination
pub fn combination(&self) -> ToneCombination
Returns the exact observation rule used for this result.
Sourcepub fn certificate(&self) -> &MultiToneCertificate
pub fn certificate(&self) -> &MultiToneCertificate
Borrows the set requirements and every component solve certificate.