ScenarioBuilder

Struct ScenarioBuilder 

pub struct ScenarioBuilder { /* private fields */ }
Reusable physical context and limits for named scenario construction.

Implementations

Source

impl ScenarioBuilder

pub fn new( frequency: Hertz, medium: ScalarMedium, singularity_radius: PositiveMetres, limits: ScenarioLimits, ) -> Self

Constructs a builder from checked physical values and explicit limits.

pub fn two_point( self, first: Point3M, second: Point3M, amplitude_per_source: FieldAmplitude, relative_phase: Radians, ) -> Result<NamedScenario, ScenarioError>

Builds two equal-amplitude ideal isotropic point sources.

pub fn counter_propagating_planes( self, centre: Point3M, axis: UnitVector3, source_separation: PositiveMetres, amplitude_per_source: FieldAmplitude, relative_phase: Radians, ) -> Result<NamedScenario, ScenarioError>

Builds equal plane waves directed into a slab around centre.

pub fn phased_array( self, centre: Point3M, element_axis: UnitVector3, elements: usize, spacing: PositiveMetres, total_amplitude: FieldAmplitude, first_phase: Radians, progressive_phase: Radians, policy: AperturePolicy, ) -> Result<NamedScenario, ScenarioError>

Builds a centred line array of ideal point elements.

pub fn discrete_aperture( self, centre: Point3M, u_axis: UnitVector3, v_axis: UnitVector3, rows: usize, columns: usize, spacing_u: PositiveMetres, spacing_v: PositiveMetres, total_amplitude: FieldAmplitude, phase: Radians, policy: AperturePolicy, ) -> Result<NamedScenario, ScenarioError>

Builds a centred rectangular aperture of equal ideal point elements.