pub enum ReferenceSolveError {
Request {
cause: Box<InterferenceError>,
},
CellGeometry {
row: usize,
column: usize,
cause: Box<InterferenceError>,
},
SourceAtCell {
source_id: String,
row: usize,
column: usize,
cause: Box<InterferenceError>,
},
NonFiniteAccumulation {
source_id: String,
row: usize,
column: usize,
component: &'static str,
value: f64,
},
AllocationFailed {
component: &'static str,
cells: usize,
},
}Expand description
A reference solve failed without returning a partial field.
Variants
Request
Sampling, work, or another request-wide preflight check failed.
Fields

cause: Box<InterferenceError>Exact core diagnostic that refused the request.
CellGeometry
A sampling cell could not be represented by the checked plane.
Fields

cause: Box<InterferenceError>Exact geometry diagnostic.
SourceAtCell
One canonical source could not be evaluated at one sampling cell.
Fields

cause: Box<InterferenceError>Exact propagation diagnostic.
NonFiniteAccumulation
Compensated component accumulation became non-finite.
Fields
AllocationFailed
Host storage could not be reserved for a complete component plane.